# SPDX-FileCopyrightText : 2024 Detlef Gebhardt, written for CircuitPython
# SPDX-FileCopyrightText : Copyright (c) 2024 Detlef Gebhardt
# SPDX-FileCopyrightText : Written for CircuitPython 9.0.5
# SPDX-Filename          : PicoBoy - Spiritlevel
# SPDX-License-Identifier: dgebhardt.de
import time
import board
import busio
import displayio
import digitalio
import terminalio
import fourwire
from adafruit_display_text import label
from adafruit_display_shapes.roundrect import RoundRect
from adafruit_display_shapes.circle import Circle
import adafruit_displayio_sh1106
import my_stk8ba58
from adafruit_progressbar.horizontalprogressbar import (
    HorizontalProgressBar, HorizontalFillDirection,)

#rote LED
led_red = digitalio.DigitalInOut(board.GP5)
led_red.direction = digitalio.Direction.OUTPUT
#grüne LED
led_green = digitalio.DigitalInOut(board.GP7)
led_green.direction = digitalio.Direction.OUTPUT
#JOY_CENTER = GP0
center = digitalio.DigitalInOut(board.GP0)
center.direction = digitalio.Direction.INPUT
center.pull = digitalio.Pull.UP

DC = board.GP8
Reset = board.GP9
CS = board.GP10
SCK = board.GP18
MOSI = board.GP19

# built-in a display
displayio.release_displays()
# Make the displayio SPI bus and the sh1106 display
spi = busio.SPI(SCK, MOSI)

# Compatibility with both CircuitPython 8.x.x and 9.x.x.
# Change it, after 8.x.x is no longer a supported release.
try:
    # Circuit 9.x.x
    from fourwire import FourWire
    display_bus = FourWire(spi, command=DC, chip_select=CS, reset=Reset, baudrate=1000000)
    display =adafruit_displayio_sh1106.SH1106(display_bus, width=132, height=64, rotation=0, brightness = 1)
except ImportError:
    # Circuit 8.x.x
    from displayio import FourWire
    display_bus = displayio.FourWire(spi, command=DC, chip_select=CS, reset=Reset, baudrate=1000000)
    display =adafruit_displayio_sh1106.SH1106(display_bus, width=132, height=64, rotation=0, brightness = 1)

# Make the display context
splash = displayio.Group()
sleep = displayio.Group()

# ACC-Sensor initialisieren
sensor=my_stk8ba58.STK8BA58() 

# Make the background bitmap when it sleeps
color_bitmap = displayio.Bitmap(128, 64, 1)
color_palette = displayio.Palette(1)
color_palette[0] = 0x000000
bg_sprite = displayio.TileGrid(color_bitmap, pixel_shader=color_palette, x=0, y=0)
sleep.append(bg_sprite)
# create the label, when it sleeps
text_label = label.Label(font=terminalio.FONT, text="PicoBoy", scale=2, color=0xffffff, line_spacing=1)
text_label.anchor_point = (0, 0)
text_label.anchored_position = (30, 0)
sleep.append(text_label)
text_label = label.Label(font=terminalio.FONT, text="press Joystick\n    to start", scale=1, color=0xffffff, line_spacing=1)
text_label.anchor_point = (0, 0)
text_label.anchored_position = (30, 40)
sleep.append(text_label)

rect1 = RoundRect(1,1,130,63,10,fill=0xffffff, outline=None)
splash.append(rect1)
rect2 = RoundRect(3,3,126,59,8,fill=0x000000, outline=None)
splash.append(rect2)

# Accelerometer Properties. Normally accelerometer well calibrated
# Will give a maximum output of 10 mts / s**2
# We create our bar displays
left_horizontal_bar = HorizontalProgressBar(
    (20, 20),(50, 25), min_value=0, max_value=2,
    direction=HorizontalFillDirection.RIGHT_TO_LEFT,
    bar_color=0x00cc00, outline_color=0xffffff, fill_color=0x606060)
splash.append(left_horizontal_bar)

right_horizontal_bar = HorizontalProgressBar(
    (70, 20), (50, 25), min_value=0, max_value=2,
    direction=HorizontalFillDirection.LEFT_TO_RIGHT,
    bar_color=0x00cc00, outline_color=0xffffff, fill_color=0x606060)
splash.append(right_horizontal_bar)


# create the label
text_label = label.Label(font=terminalio.FONT, text="  PicoBoy\n\n\n\nspirit-level", scale=1, color=0xffffff, line_spacing=0.95)
text_label.anchor_point = (0, 0)
text_label.anchored_position = (35, 4)
splash.append(text_label)

on = 0
display.root_group = sleep

while True:
    if center.value == False and on == 1:
        on = 0
        display.root_group = sleep
        led_red.value = False
        led_green.value = False
        time.sleep(1)
    if center.value == False and on == 0:
        on = 1
        display.root_group = splash
        time.sleep(1)
    if on == 1:
        #read STK8BA58
        wert_y = sensor.yAcc() * 10
        #wert_y etwas kleiner kalibrieren laut Versuchen
        wert_y = wert_y - 0.2
        if wert_y >= 0 and wert_y < 0.2 or wert_y < 0 and wert_y >= -0.2 :
            led_green.value=True
            led_red.value=False    
        # Ausschlag nach links und rechts
        if wert_y > 0 and wert_y <= 2:
            if wert_y >= 0.2:
                led_red.value = True
                led_green.value = False
            left_horizontal_bar.value = wert_y
            right_horizontal_bar.value = 0
            left_horizontal_bar.bar_color=0x00cc00
        if wert_y < 0 and wert_y >= -2:
            if wert_y <= -0.2:
                led_red.value = True
                led_green.value = False
            right_horizontal_bar.value = -wert_y
            left_horizontal_bar.value = 0
            right_horizontal_bar.bar_color=0x00cc00
        time.sleep(0.2)